@@ -4,8 +4,7 @@ favClass <- function(fav, breaks = c(0.2, 0.8), character = FALSE) {
     is.numeric(fav),
     is.numeric(breaks),
     length(breaks) == 2,
-    fav >= 0,
-    fav <= 1,
+    is.na(fav) | fav >= 0 | fav <= 1,
     breaks >= 0,
     breaks <= 1
   )
